"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  Editor: () => Editor,
  cleanedMapStr: () => cleanedMapStr,
  commonExtensions: () => commonExtensions,
  formatJson: () => formatJson,
  getRandomInt: () => getRandomInt
});
module.exports = __toCommonJS(src_exports);

// src/Editor.tsx
var import_state = require("@codemirror/state");
var import_view2 = require("@codemirror/view");
var import_codemirror_json_schema = require("codemirror-json-schema");
var import_react = __toESM(require("react"), 1);

// src/extensions.ts
var import_autocomplete = require("@codemirror/autocomplete");
var import_commands = require("@codemirror/commands");
var import_language = require("@codemirror/language");
var import_lint = require("@codemirror/lint");
var import_view = require("@codemirror/view");
var import_codemirror_theme_vscode = require("@uiw/codemirror-theme-vscode");
var commonExtensions = [
  (0, import_view.gutter)({ class: "CodeMirror-lint-markers" }),
  (0, import_language.bracketMatching)(),
  (0, import_view.highlightActiveLineGutter)(),
  // basicSetup,
  (0, import_autocomplete.closeBrackets)(),
  (0, import_commands.history)(),
  (0, import_autocomplete.autocompletion)(),
  (0, import_view.lineNumbers)(),
  (0, import_lint.lintGutter)(),
  import_language.indentUnit.of("	"),
  (0, import_language.indentOnInput)(),
  (0, import_view.drawSelection)(),
  (0, import_language.foldGutter)(),
  import_view.keymap.of([
    ...import_autocomplete.closeBracketsKeymap,
    ...import_commands.defaultKeymap,
    ...import_commands.historyKeymap,
    ...import_language.foldKeymap,
    ...import_autocomplete.completionKeymap,
    ...import_lint.lintKeymap,
    { key: "Tab", run: import_commands.insertTab },
    { key: "Shift-Tab", run: import_commands.insertTab }
  ]),
  // style
  import_codemirror_theme_vscode.vscodeDark,
  import_view.EditorView.lineWrapping
];

// src/utils.ts
function cleanedMapStr(mapString) {
  if (!mapString) {
    return "";
  }
  return mapString.replace(/\s+/g, "");
}
function getRandomInt(max) {
  return Math.floor(Math.random() * max);
}
function formatJson(jsonString, tabSize) {
  try {
    const parsed = JSON.parse(jsonString);
    return JSON.stringify(parsed, null, tabSize);
  } catch (e) {
    return jsonString;
  }
}

// src/Editor.tsx
function Editor(props) {
  const { value, onChange, schema, height = "300px", tabSize = 4, extensions } = props;
  const editorRef = (0, import_react.useRef)(null);
  const [domId] = (0, import_react.useState)(`json-schema-editor-${getRandomInt(1e3)}`);
  (0, import_react.useEffect)(() => {
    const lastExtensions = [
      commonExtensions,
      import_view2.EditorView.theme({
        "&": {
          height
        }
      }),
      import_state.EditorState.tabSize.of(tabSize),
      import_view2.EditorView.domEventHandlers({
        paste(event, view) {
          const clipboardData = event.clipboardData;
          if (!clipboardData) {
            return;
          }
          const text = clipboardData.getData("text/plain");
          const formattedText = formatJson(text, tabSize);
          if (formattedText !== text) {
            event.preventDefault();
            view.dispatch({
              changes: {
                from: view.state.selection.main.from,
                to: view.state.selection.main.to,
                insert: formattedText
              }
            });
          }
        }
      }),
      (0, import_codemirror_json_schema.jsonSchema)(schema),
      import_view2.EditorView.updateListener.of((update) => {
        if (update.docChanged) {
          onChange(update.state.doc.toString());
        }
      }),
      extensions || []
    ];
    if (!editorRef.current) {
      const state = import_state.EditorState.create({
        doc: value,
        extensions: lastExtensions
      });
      editorRef.current = new import_view2.EditorView({
        state,
        parent: document.querySelector(`#${domId}`)
      });
    } else {
      editorRef.current.dispatch({
        effects: import_state.StateEffect.reconfigure.of(lastExtensions)
      });
    }
  }, [height, tabSize, commonExtensions, extensions]);
  (0, import_react.useEffect)(() => {
    if (cleanedMapStr(value) !== cleanedMapStr(editorRef.current?.state.doc.toString())) {
      editorRef.current?.dispatch({
        changes: { from: 0, to: editorRef.current?.state.doc.length, insert: value }
      });
    }
  }, [value]);
  (0, import_react.useEffect)(() => {
    if (editorRef.current) {
      (0, import_codemirror_json_schema.updateSchema)(editorRef.current, schema);
    }
  }, [schema]);
  return /* @__PURE__ */ import_react.default.createElement("div", { id: domId });
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  Editor,
  cleanedMapStr,
  commonExtensions,
  formatJson,
  getRandomInt
});
